/*

  This file is part of womb (warp's own multiboot), a tool to communicate 
  with the Nintendo Gameboy Advance handheld game console.
  Copyright 2002 Kuno Woudt <warp-tmt@dds.nl>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; see the file copying.txt; if not, write to
  the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  Boston, MA  02111-1307  USA

*/

#include <stdio.h>
#include <stdarg.h>

static char *programname;
static FILE *msg_handle;
static int msg_verbose;


/*   ______     ______     _______ ,---.____  init error handler.
 ,---\    /---./      \,--//      \|  //_   \ 
  \   \  /|       /|       |/  \        /   / =================================
   \______\\--,____\\------/____\--,_______/  womb - pc->gba multiboot transfer
*/
void
womb_msg_init (char *progname, FILE *handle)
{
  programname = progname;
  msg_handle = handle;
}

void
womb_msg_setverbose (int verbose)
{
  msg_verbose = verbose;
}

/*   ______     ______     _______ ,---.____  info/error/warning messages.
 ,---\    /---./      \,--//      \|  //_   \ 
  \   \  /|       /|       |/  \        /   / =================================
   \______\\--,____\\------/____\--,_______/  womb - pc->gba multiboot transfer
*/
void
womb_msg (int priority, const char *template, ...)
{
  if (priority <= msg_verbose)
    {
      va_list ap;
     
      fprintf (msg_handle, "%s: ", programname);
      va_start (ap, template);
      vfprintf (msg_handle, template, ap);
      va_end (ap);
      fprintf (msg_handle, "\n");
    }
}

/*   ______     ______     _______ ,---.____  informational banners.
 ,---\    /---./      \,--//      \|  //_   \ 
  \   \  /|       /|       |/  \        /   / =================================
   \______\\--,____\\------/____\--,_______/  womb - pc->gba multiboot transfer
*/
void
womb_banner (int priority, const char *template, ...)
{
  if (priority <= msg_verbose)
    {
      va_list ap;
     
      va_start (ap, template);
      vfprintf (msg_handle, template, ap);
      va_end (ap);
      fprintf (msg_handle, "\n");
    }
}

/*   ______     ______     _______ ,---.____  fatal error messages.
 ,---\    /---./      \,--//      \|  //_   \ 
  \   \  /|       /|       |/  \        /   / =================================
   \______\\--,____\\------/____\--,_______/  womb - pc->gba multiboot transfer
*/
void
womb_fatal (const char *template, ...)
{
  va_list ap;
     
  fprintf (msg_handle, "%s: ", programname);
  va_start (ap, template);
  vfprintf (msg_handle, template, ap);
  va_end (ap);
  fprintf (msg_handle, "\n");
  
  exit (1);
}

/*   ______     ______     _______ ,---.____  no newline, no template msg.
 ,---\    /---./      \,--//      \|  //_   \ 
  \   \  /|       /|       |/  \        /   / =================================
   \______\\--,____\\------/____\--,_______/  womb - pc->gba multiboot transfer
*/
void
womb_msg_short (int priority, unsigned char * msg)
{
  if (priority <= msg_verbose)
    printf (msg);
}

